@@ -77,12 +77,7 @@
      "http://www.gnu.org/software/dejagnu/")
     (synopsis "GNU software testing framework")
     (description
-     "DejaGnu is a framework for testing other programs.  Its purpose
-is to provide a single front end for all tests.  Think of it as a
-custom library of Tcl procedures crafted to support writing a
-test harness.  A test harness is the testing infrastructure that
-is created to support a specific program or tool.  Each program
-can have multiple testsuites, all supported by a single test
-harness.  DejaGnu is written in Expect, which in turn uses Tcl --
-Tool command language.")
+     "DejaGnu is a framework for testing software.  In effect, it serves as
+a front-end for all tests written for a program.  Thus, each program can have
+multiple test suites, which are then all managed by a single harness.")
     (license gpl2+)))
