@@ -30,9 +30,7 @@
   #:use-module (gnu packages guile)
   #:use-module (gnu packages xorg)
   #:use-module (gnu packages lesstif)
-  #:use-module (gnu packages libjpeg)
-  #:use-module (gnu packages libtiff)
-  #:use-module (gnu packages libpng)
+  #:use-module (gnu packages image)
   #:use-module (gnu packages giflib)
   #:use-module (gnu packages linux)
   #:use-module ((gnu packages compression)
