@@ -21,8 +21,7 @@
   #:use-module (guix build-system gnu)
   #:use-module (guix download)
   #:use-module (gnu packages)
-  #:use-module (gnu packages libpng)
-  #:use-module (gnu packages libjpeg)
+  #:use-module (gnu packages image)
   #:use-module (gnu packages fontutils)
   #:use-module (gnu packages compression)
   #:use-module ((guix licenses) #:select (bsd-style)))
