@@ -242,12 +242,14 @@ many readers as needed).")
                                  version ".tar.gz"))
              (sha256
               (base32
-               "070wl664lsm14hb6y9ch97x9q6cns4k6nxgdzbdzi5byixn74899"))))
+               "070wl664lsm14hb6y9ch97x9q6cns4k6nxgdzbdzi5byixn74899"))
+             (patches (list (search-patch "guile-ncurses-tests.patch")))))
     (build-system gnu-build-system)
     (inputs `(("ncurses" ,ncurses)
               ("guile" ,guile-2.0)))
     (arguments
-     '(#:configure-flags (list (string-append "--with-guilesitedir="
+     '(#:configure-flags (list "--with-ncursesw"  ; Unicode support
+                               (string-append "--with-guilesitedir="
                                               (assoc-ref %outputs "out")
                                               "/share/guile/site/2.0"))
        #:phases (alist-cons-after
@@ -271,18 +273,18 @@ library.")
 (define-public mcron
   (package
     (name "mcron")
-    (version "1.0.6")
+    (version "1.0.8")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/mcron/mcron-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "0yvrfzzdy2m7fbqkr61fw01wd9r2jpnbyabxhcsfivgxywknl0fy"))
+               "0zparwgf01jgl1x53ik71ghabldq6zz18ha4dscps1i0qrzgap1b"))
              (patches (list (search-patch "mcron-install.patch")))))
     (build-system gnu-build-system)
-    (inputs
-     `(("ed" ,ed) ("which" ,which) ("guile" ,guile-1.8)))
+    (native-inputs `(("pkg-config" ,pkg-config)))
+    (inputs `(("ed" ,ed) ("which" ,which) ("guile" ,guile-2.0)))
     (home-page "http://www.gnu.org/software/mcron/")
     (synopsis "Run jobs at scheduled times")
     (description
