@@ -21,16 +21,23 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages version-control)
-  #:use-module ((guix licenses) #:select (asl2.0 gpl1+ gpl2 gpl2+ gpl3+))
+  #:use-module ((guix licenses)
+                #:select (asl2.0 gpl1+ gpl2 gpl2+ gpl3+ x11-style))
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix build-system gnu)
   #:use-module (guix build-system python)
   #:use-module (guix build utils)
   #:use-module (gnu packages apr)
+  #:use-module (gnu packages bison)
+  #:use-module (gnu packages cook)
   #:use-module (gnu packages curl)
   #:use-module (gnu packages ed)
+  #:use-module (gnu packages file)
+  #:use-module (gnu packages flex)
   #:use-module (gnu packages gettext)
+  #:use-module (gnu packages groff)
+  #:use-module (gnu packages linux)
 ;;   #:use-module (gnu packages gnutls)
   #:use-module (gnu packages nano)
   #:use-module (gnu packages openssl)
@@ -43,7 +50,8 @@
   #:use-module (gnu packages emacs)
   #:use-module (gnu packages compression)
   #:use-module (gnu packages swig)
-  #:use-module (gnu packages tcl))
+  #:use-module (gnu packages tcl)
+  #:use-module (gnu packages))
 
 (define-public bazaar
   (package
@@ -413,3 +421,152 @@ when a file change has been described in the ChangeLog but the file has not
 been added to the VC.  vc-chlog scans changed files and generates
 standards-compliant ChangeLog entries based on the changes that it detects.")
     (license gpl3+)))
+
+(define-public diffstat
+  (package
+    (name "diffstat")
+    (version "1.58")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append
+                    "ftp://invisible-island.net/diffstat/diffstat-"
+                    version ".tgz"))
+              (sha256
+               (base32
+                "14rpf5c05ff30f6vn6pn6pzy0k4g4is5im656ahsxff3k58i7mgs"))))
+    (build-system gnu-build-system)
+    (home-page "http://invisible-island.net/diffstat/")
+    (synopsis "Make histograms from the output of 'diff'")
+    (description
+     "diffstat reads the output of 'diff' and displays a histogram of the
+insertions, deletions, and modifications per-file.  It is useful for reviewing
+large, complex patch files.")
+    (license (x11-style "file://COPYING"))))
+
+(define-public cssc
+  (package
+    (name "cssc")
+    (version "1.3.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://gnu/" name "/CSSC-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "0bkw6fjh20ppvn54smv05461lm1vcwvn02avx941c4acafmkl1cm"))
+              (patches (list (search-patch "cssc-gets-undeclared.patch")
+                             (search-patch "cssc-missing-include.patch")))))
+    (build-system gnu-build-system)
+    (arguments
+     `(#:phases (alist-cons-before
+                 'check 'precheck
+                 (lambda _
+                   (begin
+                     (substitute* "tests/common/test-common"
+                       (("/bin/pwd") (which "pwd")))
+
+                     (substitute* "tests/prt/all-512.sh"
+                       (("/bin/sh") (which "sh")))
+
+                     ;; XXX: This test has no hope of passing until there is a "nogroup"
+                     ;; entry (or at least some group to which the guix builder does
+                     ;; not belong) in the /etc/group file of the build environment.
+                     ;; Currently we do not have such a group.  Disable this test for now.
+                     (substitute* "tests/Makefile"
+                       (("test-delta ") ""))))
+                 %standard-phases)))
+    ;; These are needed for the tests
+    (native-inputs `(("git" ,git)
+                     ("cvs" ,cvs)))
+    (home-page "http://www.gnu.org/software/cssc/")
+    (synopsis "File-based version control like SCCS")
+    (description  "GNU CSSC provides a replacement for the legacy Unix source
+code control system SCCS.  This allows old code still under that system to be
+accessed and migrated on modern systems.")
+    (license gpl3+)))
+
+;; This package can unfortunately work only in -TEST mode, since Aegis 
+;; requires that it is installed setuid root.
+(define-public aegis
+  (package
+    (name "aegis")
+    (version "4.24")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/aegis/aegis-" 
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "18s86ssarfmc4l17gbpzybca29m5wa37cbaimdji8czlcry3mcjl"))
+            (patches (list (search-patch "aegis-perl-tempdir1.patch")
+                           (search-patch "aegis-perl-tempdir2.patch")
+                           (search-patch "aegis-test-fixup-1.patch")
+                           (search-patch "aegis-test-fixup-2.patch")
+                           (search-patch "aegis-constness-error.patch")))))
+    (build-system gnu-build-system)
+    (inputs
+     `(("e2fsprogs" ,e2fsprogs)
+       ("curl" ,curl)
+       ("file" ,file)
+       ("libxml2" ,libxml2)
+       ("zlib" ,zlib)
+       ("gettext" ,gnu-gettext)))
+    (native-inputs
+     `(("bison" ,bison)
+       ("groff" ,groff)
+       ("perl" ,perl)
+       ;; Various tests require the following:
+       ("cvs" ,cvs) 
+       ("flex" ,flex)
+       ("cook" ,cook)
+       ("subversion" ,subversion)
+       ("rcs" ,rcs)
+       ("ed" ,ed)))
+    (arguments
+     `(#:configure-flags (list "--with-no-aegis-configured" 
+                               "--sharedstatedir=/var/com/aegis")
+       #:parallel-build? #f ; There are some nasty racy rules in the Makefile.
+       #:phases 
+        (alist-cons-before
+         'configure 'pre-conf
+         (lambda _
+             (substitute* (append '("configure"
+                                    "etc/check-tar-gz.sh"
+                                    "etc/patches.sh"
+                                    "etc/test.sh"
+                                    "script/aexver.in"
+                                    "script/aebisect.in"
+                                    "script/aeintegratq.in"
+                                    "script/tkaegis.in"
+                                    "script/test_funcs.in"
+                                    "web/eg_oss_templ.sh"
+                                    "web/webiface.html"
+                                    "libaegis/getpw_cache.cc")
+                                  (find-files "test" "\\.sh"))
+               (("/bin/sh") (which "sh")))
+             (setenv "SH" (which "sh")))
+         (alist-replace
+          'check
+          (lambda _
+            (let ((home (string-append (getcwd) "/my-new-home")))
+              ;; Some tests need to write to $HOME.
+              (mkdir home)
+              (setenv "HOME" home)
+
+              ;; This test assumes that  flex has been symlinked to "lex".
+              (substitute* "test/00/t0011a.sh"
+                (("type lex")  "type flex"))
+
+              ;; The author decided to call the check rule "sure".
+              (zero? (system* "make" "sure"))))
+         %standard-phases))))
+    (home-page "http://aegis.sourceforge.net")
+    (synopsis "Project change supervisor")
+    (description "Aegis is a project change supervisor, and performs some of
+the Software Configuration Management needed in a CASE environment. Aegis
+provides a framework within which a team of developers may work on many
+changes to a program independently, and Aegis coordinates integrating these
+changes back into the master source of the program, with as little disruption
+as possible. Resolution of contention for source files, a major headache for
+any project with more than one developer, is one of Aegis's major functions.")
+    (license gpl3+)))
